__defineBuiltinComponent('rich-text', { js: function (BuiltinComponent, wx, mmp) {
            "use strict";

var hm = function () {
  var elements = {
    a: {
      name: 'a',
      attrs: []
    },
    abbr: {
      name: 'abbr',
      attrs: []
    },
    address: {
      name: 'address',
      attrs: []
    },
    article: {
      name: 'article',
      attrs: []
    },
    aside: {
      name: 'aside',
      attrs: []
    },
    b: {
      name: 'b',
      attrs: []
    },
    bdi: {
      name: 'bdi',
      attrs: []
    },
    bdo: {
      name: 'bdo',
      attrs: ['dir']
    },
    big: {
      name: 'big',
      attrs: []
    },
    blockquote: {
      name: 'blockquote',
      attrs: []
    },
    br: {
      name: 'br',
      attrs: [],
      isSingleTag: true
    },
    code: {
      name: 'code',
      attrs: []
    },
    caption: {
      name: 'caption',
      attrs: []
    },
    center: {
      name: 'center',
      attrs: []
    },
    cite: {
      name: 'cite',
      attrs: []
    },
    col: {
      name: 'col',
      attrs: ['span', 'width'],
      isSingleTag: true
    },
    colgroup: {
      name: 'colgroup',
      attrs: ['span', 'width']
    },
    dd: {
      name: 'dd',
      attrs: []
    },
    del: {
      name: 'del',
      attrs: []
    },
    div: {
      name: 'div',
      attrs: []
    },
    dl: {
      name: 'dl',
      attrs: []
    },
    dt: {
      name: 'dt',
      attrs: []
    },
    em: {
      name: 'em',
      attrs: []
    },
    fieldset: {
      name: 'fieldset',
      attrs: []
    },
    font: {
      name: 'font',
      attrs: []
    },
    footer: {
      name: 'footer',
      attrs: []
    },
    h1: {
      name: 'h1',
      attrs: []
    },
    h2: {
      name: 'h2',
      attrs: []
    },
    h3: {
      name: 'h3',
      attrs: []
    },
    h4: {
      name: 'h4',
      attrs: []
    },
    h5: {
      name: 'h5',
      attrs: []
    },
    h6: {
      name: 'h6',
      attrs: []
    },
    header: {
      name: 'header',
      attrs: []
    },
    hr: {
      name: 'hr',
      attrs: [],
      isSingleTag: true
    },
    i: {
      name: 'i',
      attrs: []
    },
    img: {
      name: 'img',
      attrs: ['alt', 'src', 'height', 'width'],
      isSingleTag: true
    },
    ins: {
      name: 'ins',
      attrs: []
    },
    label: {
      name: 'label',
      attrs: []
    },
    legend: {
      name: 'legend',
      attrs: []
    },
    li: {
      name: 'li',
      attrs: []
    },
    mark: {
      name: 'mark',
      attrs: []
    },
    nav: {
      name: 'nav',
      attrs: []
    },
    ol: {
      name: 'ol',
      attrs: ['start', 'type']
    },
    p: {
      name: 'p',
      attrs: [],
      isSingleTag: true
    },
    pre: {
      name: 'pre',
      attrs: []
    },
    q: {
      name: 'q',
      attrs: []
    },
    rt: {
      name: 'rt',
      attrs: []
    },
    ruby: {
      name: 'ruby',
      attrs: []
    },
    s: {
      name: 's',
      attrs: []
    },
    section: {
      name: 'section',
      attrs: []
    },
    small: {
      name: 'small',
      attrs: []
    },
    span: {
      name: 'span',
      attrs: []
    },
    strong: {
      name: 'strong',
      attrs: []
    },
    sub: {
      name: 'sub',
      attrs: []
    },
    sup: {
      name: 'sup',
      attrs: []
    },
    table: {
      name: 'table',
      attrs: ['width']
    },
    tbody: {
      name: 'tbody',
      attrs: []
    },
    td: {
      name: 'td',
      attrs: ['colspan', 'height', 'rowspan', 'width']
    },
    tfoot: {
      name: 'tfoot',
      attrs: []
    },
    th: {
      name: 'th',
      attrs: ['colspan', 'height', 'rowspan', 'width']
    },
    thead: {
      name: 'thead',
      attrs: []
    },
    tr: {
      name: 'tr',
      attrs: []
    },
    tt: {
      name: 'tt',
      attrs: []
    },
    u: {
      name: 'u',
      attrs: []
    },
    ul: {
      name: 'ul',
      attrs: []
    }
  }; // 所有标签都支持class和style属性

  Object.keys(elements).forEach(function (nodeName) {
    elements[nodeName].attrs.push('style', 'class');
  });

  function isSingleTag(tag) {
    return elements[tag.toLowerCase()].isSingleTag;
  }

  function has(tag) {
    return elements[tag.toLowerCase()] !== undefined;
  }

  function find(tag) {
    return elements[tag.toLowerCase()];
  }

  return {
    elements: elements,
    isSingleTag: isSingleTag,
    has: has,
    find: find
  };
}();

var ast2vnode = function () {
  var attrParser = {
    run: function run(attrs, owner) {
      var ret = {
        meta: {},
        props: {}
      };
      Object.keys(attrs).forEach(function (attrName) {
        // 不支持 id 属性
        if (attrName === 'id') {
          return;
        } else if (attrName === 'class' && attrs.class) {
          // class 要加 prefix
          var prefix = owner.define.prefix || '';
          ret.meta.class = attrs.class.split(/\s+/).map(function (name) {
            return "".concat(prefix).concat(name);
          }).join(' ');
        } else if (attrName === 'style') {
          ret.meta.style = attrs.style;
        } else {
          ret.props[attrName] = attrs[attrName];
        }
      });
      return ret;
    }
  }; // 将微信 rich-text 支持的 html ast 转换成 Vue 的 vnode

  return function ast2vnode(ast, h, owner, space) {
    var nodes = [];

    if (Array.isArray(ast)) {
      ast.forEach(function (node) {
        var tagName = '';
        var attrs = {};
        var children = [];

        if (node.type === 'text') {
          tagName = 'span';
          attrs.html = space ? remainSpace(node.text, space) : node.text;
        } else {
          tagName = node.name || '';
          var nodeSpec = hm.find(tagName); // 只支持指定的 html 元素

          if (!nodeSpec) {
            return;
          } // 格式化 attrs，并过滤掉不支持的属性


          if (node.attrs) {
            var allowedAttrs = {};
            nodeSpec.attrs.forEach(function (attrName) {
              allowedAttrs[attrName] = node.attrs[attrName];
            });
            attrs = attrParser.run(allowedAttrs, owner);
          }

          children = Array.isArray(node.children) ? ast2vnode(node.children, h, owner, space) : node.children;
        }

        nodes.push(h(tagName, attrs, children));
      });
    }

    return nodes;
  };
}();

function arrayFind(arr, predicate) {
  var list = Object(arr);
  var length = list.length >>> 0;
  var thisArg = arguments[2];

  for (var i = 0; i < length; i++) {
    var item = list[i];

    if (predicate.call(thisArg, item, i, list)) {
      return item;
    }
  }

  return undefined;
}

function filter(html, space, owner) {
  var pattern = /<\/?([^<>/\s]+)(?:\s+[^<>]+)*\/?>/;
  var tokens = [];

  function remove(endTag, idx) {
    var hasStartTag = false;

    for (var i = idx - 1; i >= 0; i -= 1) {
      if (tokens[i].tagName === endTag.tagName) {
        hasStartTag = true;
        tokens.splice(i, idx - i + 1);
        break;
      }
    }

    if (!hasStartTag) {
      throw new Error("No matching start tag found for </".concat(endTag.tagName, ">"));
    }
  }

  while (html) {
    var matched = pattern.exec(html);

    if (!matched) {
      tokens.push({
        type: 'text',
        html: html
      });
      break;
    }

    var str = matched[0];
    var tagName = matched[1];
    var index = matched.index;

    if (index > 0) {
      tokens.push({
        type: 'text',
        html: space ? remainSpace(html.slice(0, index), space) : html.slice(0, index)
      });
      html = html.slice(index);
    }

    tokens.push({
      type: 'node',
      tagName: tagName,
      html: str
    });
    html = html.slice(str.length);
  } // eslint-disable-next-line no-constant-condition


  while (true) {
    var idx = void 0;
    var endTag = arrayFind(tokens, function (t, i) {
      if (t.type === 'node' && !hm.has(t.tagName) && t.html.charAt(1) === '/') {
        idx = i;
        return true;
      }

      return false;
    });

    if (endTag) {
      remove(endTag, idx);
      continue;
    }

    var startTag = arrayFind(tokens, function (t, i) {
      if (t.type === 'node' && !hm.has(t.tagName) && t.html.charAt(1) !== '/') {
        idx = i;
        return true;
      }

      return false;
    });

    if (startTag) {
      var next = tokens[idx + 1];
      var c = !/\/>$/.test(startTag.html) && next && next.type === 'text' ? 2 : 1;
      tokens.splice(idx, c);
      continue;
    }

    break;
  }

  var prefix = owner.define.prefix || '';
  var result = tokens.map(function (t) {
    if (t.type === 'node' && t.html.charAt(1) !== '/' && prefix !== '') {
      var _html = t.html;
      var legalAttributeNames = hm.find(t.tagName).attrs;
      _html = _html.replace(/(\w+)=".*?"/g, function (match, p1) {
        return match && legalAttributeNames.indexOf(p1) !== -1 ? match : '';
      }); // regex 里面两个class前有一个空格 注意不要消除

      var prefixHtml = _html.replace(/ class="([^"]+)"| class='([^']+)'/g, function (match, p1, p2) {
        return " class=\"".concat((p1 || p2).split(/\s+/).map(function (className) {
          return prefix.concat(className);
        }).join(' '), "\"");
      });

      return prefixHtml;
    }

    return t.html;
  }).join('');
  return result;
}

function remainSpace(str, space) {
  var spaceNode = '';

  switch (space) {
    case 'ensp':
      spaceNode = '&ensp;';
      break;

    case 'emsp':
      spaceNode = '&emsp;';
      break;

    case 'nbsp':
      spaceNode = '&nbsp;';
      break;
  }

  return spaceNode ? str.replace(/ +/g, function (matched) {
    return spaceNode.repeat(matched.length);
  }) : str;
}

BuiltinComponent('mt-rich-text', {
  properties: {
    nodes: {
      type: [Array, String],
      value: []
    },
    space: {
      type: String,
      value: ''
    }
  },
  render: function render(h) {
    var _this$data = this.data,
        nodes = _this$data.nodes,
        space = _this$data.space;
    var owner = this.getComponentInstance().getOwner();

    if (typeof nodes === 'string') {
      return h('div', {
        html: filter(nodes, space, owner)
      });
    }

    return h('div', null, ast2vnode(nodes, h, owner, space));
  }
});
          } });